@@ -20,6 +20,7 @@ import json
 import os
 import secrets
 from datetime import datetime
+from typing import List
 
 import utoken
 
@@ -298,7 +299,6 @@ class Pie(object):
 
     def _get_last_piece_hash(self, filepath: str) -> str:
         pieces_refs = self._get_pieces_refs()
-        repo_info = self._get_repo_info()
         file = pieces_refs['tracked'][filepath]
 
         commits = pieces_refs['commits']
@@ -316,6 +316,51 @@ class Pie(object):
 
         return hashlib.sha256(piece_json).hexdigest()
 
+    def get_commits(self) -> dict:
+        """Return all commits.
+
+        :return: Commits in a dict.
+        :rtype: dict
+        """
+
+        pieces_refs = self._get_pieces_refs()
+        return pieces_refs['commits']
+
+    def _file_has_changed(self, filepath: str) -> bool:
+        previous_file_lines = self.join_file_changes(filepath)
+        current_file_lines = self.index_file_lines(filepath)
+
+        previous_file_lines_json = json.dumps(previous_file_lines).encode()
+        previous_hash = hashlib.md5(previous_file_lines_json).hexdigest()
+
+        current_file_lines_json = json.dumps(current_file_lines).encode()
+        current_hash = hashlib.md5(current_file_lines_json).hexdigest()
+
+        return previous_hash != current_hash
+
+    def get_files_status(self) -> List[dict]:
+        pieces_refs = self._get_pieces_refs()
+        tracked_files = pieces_refs['tracked']
+
+        files_status = []
+
+        for filepath, info in tracked_files.items():
+            if not info['commits']:
+                files_status.append({
+                    'filepath': filepath,
+                    'status': 'new'
+                })
+            else:
+                file_has_changed = self._file_has_changed(filepath)
+                
+                if file_has_changed:
+                    files_status.append({
+                        'filepath': filepath,
+                        'status': 'uncommitted'
+                    })
+
+        return files_status
+
     def commit(self, filepath_list: list, message: str) -> dict:
         """Commit the files.
 
